@@ -1,5 +1,5 @@
 from wedeliver_core import WeDeliverCore
-from wedeliver_core.wedeliver_core.helpers.sql import sql
+from wedeliver_core.helpers.sql import sql
 import importlib
 import os
 
